@@ -4,7 +4,7 @@ use warnings;
 use strict;
 use 5.10.0;
 
-our $VERSION = '0.149';
+our $VERSION = '0.150';
 use Exporter 'import';
 our @EXPORT_OK = qw( print_table );
 
@@ -755,9 +755,9 @@ sub __search {
     if ( ! $self->{search} ) {
         return;
     }
-    require Term::Form;
-    Term::Form->VERSION(0.530);
-    my $term = Term::Form->new();
+    require Term::Form::ReadLine;
+    Term::Form::ReadLine->VERSION(0.544);
+    my $term = Term::Form::ReadLine->new();
     my $error_message;
     my $prompt = '> search-pattern: ';
     my $default = '';
@@ -884,7 +884,7 @@ Term::TablePrint - Print a table to the terminal and browse it interactively.
 
 =head1 VERSION
 
-Version 0.149
+Version 0.150
 
 =cut
 
@@ -1270,7 +1270,7 @@ Matthäus Kiem <cuer2s@gmail.com>
 
 =head1 LICENSE AND COPYRIGHT
 
-Copyright 2013-2021 Matthäus Kiem.
+Copyright 2013-2022 Matthäus Kiem.
 
 This library is free software; you can redistribute it and/or modify it under the same terms as Perl 5.10.0. For
 details, see the full text of the licenses in the file LICENSE.
